@@ -7,6 +7,6 @@ from . import _callbacks as callbacks
 
 from . _marple_sequence import marple_sequence
 
-from .__modulated import modulated_signal
+from ._modulated import modulated_signal
 
 from . import _modulated_utilits as modulations
